@@ -21,20 +21,25 @@ logger = logging.getLogger(__name__)
 
 class ObjectStorage(metaclass=SingletonMeta):
     def __init__(self, settings: S3Settings):
-        if not settings.s3_endpoint_url:
-            raise ValueError('s3_endpoint_url must be set')
-
         self._session = aiobotocore.session.get_session()
-        self._config = {
-            'endpoint_url': settings.s3_endpoint_url,
+        config = {
             'region_name': settings.s3_region_name,
-            'aws_access_key_id': settings.s3_access_key_id.get_secret_value(),
-            'aws_secret_access_key': settings.s3_secret_access_key.get_secret_value(),
             'use_ssl': settings.s3_secure,
             'verify': settings.s3_cert_verify,
             'config': Config(s3={'addressing_style': settings.s3_addressing_style}, signature_version='s3v4'),
         }
 
+        if s3_endpoint_url := settings.s3_endpoint_url:
+            config['endpoint_url'] = s3_endpoint_url
+
+        if s3_access_key_id := settings.s3_access_key_id:
+            config['aws_access_key_id'] = s3_access_key_id.get_secret_value()
+
+        if s3_secret_access_key := settings.s3_secret_access_key:
+            config['aws_secret_access_key'] = s3_secret_access_key.get_secret_value()
+
+        self._config = config
+
     @asynccontextmanager
     async def get_client(self) -> AsyncGenerator[S3Client, None]:
         async with self._session.create_client('s3', **self._config) as client:
